"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AdRecord = void 0;
const errors_1 = require("../utils/errors");
const db_1 = require("../db/db");
const uuid_1 = require("uuid");
const valid_url_1 = require("valid-url");
class AdRecord {
    constructor(obj) {
        var _a;
        if (!obj.name || obj.name.length > 100) {
            throw new errors_1.ValidationError('Ad name should be between 1 and 100 characters long');
        }
        if (obj.description.length > 1000) {
            throw new errors_1.ValidationError('Ad description cannot be longer then 1000 characters');
        }
        if (obj.price < 0 || obj.price > 9999999) {
            throw new errors_1.ValidationError('Ad price should be between 0 - 9999999 EUR');
        }
        if (!obj.url) {
            throw new errors_1.ValidationError('Link is obligatory');
        }
        if (!(0, valid_url_1.isUri)(obj.url)) {
            throw new errors_1.ValidationError('Link address is not proper');
        }
        if (!obj.lat || !obj.lon) {
            throw new errors_1.ValidationError('We cannot locate the ad');
        }
        this.id = (_a = obj.id) !== null && _a !== void 0 ? _a : (0, uuid_1.v4)();
        this.name = obj.name;
        this.description = obj.description;
        this.price = obj.price;
        this.url = obj.url;
        this.lat = obj.lat;
        this.lon = obj.lon;
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [[oneAd]] = yield db_1.pool.execute('SELECT * FROM `ads` WHERE `id` = :id', {
                id
            });
            return oneAd ? new AdRecord(oneAd) : null;
        });
    }
    static findAll(phrase) {
        return __awaiter(this, void 0, void 0, function* () {
            const [found] = yield db_1.pool.execute("SELECT `id`, `lat`, `lon` FROM `ads` WHERE `name` LIKE :phrase", {
                phrase: `%${phrase}%`
            });
            return found;
        });
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `ads` VALUES (:id, :name, :description, :price, :url, :lat, :lon)", {
                id: this.id,
                name: this.name,
                description: this.description,
                price: this.price,
                url: this.url,
                lat: this.lat,
                lon: this.lon,
            });
            return this.id;
        });
    }
}
exports.AdRecord = AdRecord;
//# sourceMappingURL=ad.record.js.map