"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.defaultAd = void 0;
const ad_record_1 = require("../records/ad.record");
beforeAll(() => {
    exports.defaultAd = new ad_record_1.AdRecord({
        name: "Test name",
        description: 'very long desc',
        url: 'https://test.test.pl',
        lat: 50,
        lon: 50,
        price: 70
    });
});
test('Can build AdRecord', () => {
    expect(exports.defaultAd.id).toBeDefined();
    expect(exports.defaultAd.name).toEqual('Test name');
    expect(exports.defaultAd.description).toBe('very long desc');
    expect(exports.defaultAd.url).toBe('https://test.test.pl');
    expect(exports.defaultAd.price).toEqual(70);
    expect(exports.defaultAd.lon).toEqual(50);
    expect(exports.defaultAd.lat).toEqual(50);
});
test('Validates invalid price', () => {
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { price: -1 }))).toThrow('Ad price should be between 0 - 9999999 EUR');
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { price: 10999999 }))).toThrow('Ad price should be between 0 - 9999999 EUR');
});
test('Validates invalid name', () => {
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { name: '' }))).toThrow('Ad name should be between 1 and 100 characters long');
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { name: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum.' }))).toThrow('Ad name should be between 1 and 100 characters long');
});
test(')Validates invalid description', () => {
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { description: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. ' }))).toThrow('Ad description cannot be longer then 1000 characters');
});
test('Validates lack of url', () => {
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { url: '' }))).toThrow();
});
test('Validates invalid url', () => {
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { url: 'no-url.com' }))).toThrow();
});
test('validates invalid lat and lon', () => {
    expect(() => new ad_record_1.AdRecord(Object.assign(Object.assign({}, exports.defaultAd), { lat: 0, lon: 0 }))).toThrow('We cannot locate the ad');
});
//# sourceMappingURL=ad-record.test.js.map