"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ad_record_1 = require("../records/ad.record");
const ad_record_test_1 = require("./ad-record.test");
const uuid_1 = require("uuid");
let newAd;
beforeAll(() => {
    newAd = new ad_record_1.AdRecord(ad_record_test_1.defaultAd);
});
// afterAll(async () => {
//     await pool.end();
// })
jest
    .spyOn(ad_record_1.AdRecord, 'getOne')
    .mockImplementation((id) => __awaiter(void 0, void 0, void 0, function* () {
    if (id === 'bca') {
        return null;
    }
    return new ad_record_1.AdRecord({
        id,
        name: 'testowa',
        description: 'testowy opis',
        price: 99.99,
        url: 'https://test.test.pl',
        lat: 49.1553514,
        lon: 22.4681735,
    });
}));
jest
    .spyOn(ad_record_1.AdRecord.prototype, 'insert')
    .mockImplementation(() => __awaiter(void 0, void 0, void 0, function* () {
    return (0, uuid_1.v4)();
}));
jest
    .spyOn(ad_record_1.AdRecord, 'findAll')
    .mockImplementation((phrase) => __awaiter(void 0, void 0, void 0, function* () {
    const dbMock = [
        {
            id: 'cvb',
            name: 'testowa',
            description: 'testowy opis',
            price: 99.99,
            url: 'test.test.pl',
            lat: 49.1553514,
            lon: 22.4681735,
        },
        {
            id: 'xyz',
            name: 'testowy anons',
            description: 'testowa zawartość',
            price: 33.99,
            url: 'test.test.pl',
            lat: 21.1553514,
            lon: 34.4681735,
        },
        {
            id: 'bnm',
            name: 'testowy',
            description: 'testowy opis opisu',
            price: 0,
            url: 'test.test.com',
            lat: 43.1553514,
            lon: 22.4681735,
        },
    ];
    const dbResult = dbMock.filter(ad => ad.name.includes(phrase));
    return dbResult.map(oneAd => {
        const { id, lat, lon } = oneAd;
        return {
            id,
            lat,
            lon,
        };
    });
}));
// getOne()
test('AdRecords.getOne returns data from db for single record', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('abc');
    expect(ad).toBeDefined();
    expect(ad instanceof ad_record_1.AdRecord).toBeTruthy();
    expect(ad.id).toBe('abc');
    expect(ad.name).toBe('testowa');
    expect(ad.description).toBe('testowy opis');
    expect(ad.price).toEqual(99.99);
    expect(ad.url).toEqual('https://test.test.pl');
    expect(ad.lat).toEqual(49.1553514);
    expect(ad.lon).toEqual(22.4681735);
}));
test('AdRecord.getOne  returns null for unexciting record', () => __awaiter(void 0, void 0, void 0, function* () {
    const ad = yield ad_record_1.AdRecord.getOne('bca');
    expect(ad).toBeNull();
}));
// findAll()
test('AdRecord.findAll returns matching records with simple structure', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('a');
    expect(ads.length).toEqual(2);
    expect(ads[0]).toBeDefined();
    expect(ads[0].id).toBeDefined();
    expect(ads[0].lat).toBeDefined();
    expect(ads[0].lon).toBeDefined();
    expect(ads[0].name).toBeUndefined();
    expect(ads[0].description).toBeUndefined();
    expect(ads[0].url).toBeUndefined();
    expect(ads[0].price).toBeUndefined();
}));
test('AdRecord.findAll returns all records with simple structure when argument = ""', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('');
    expect(ads).not.toStrictEqual([]);
    expect(ads.length).toEqual(3);
    expect(ads[0].id).toBeDefined();
    expect(ads[0].lat).toBeDefined();
    expect(ads[0].lon).toBeDefined();
    expect(ads[0].name).toBeUndefined();
    expect(ads[0].description).toBeUndefined();
    expect(ads[0].url).toBeUndefined();
    expect(ads[0].price).toBeUndefined();
}));
test('AdRecord.findAll returns empty array when did not find record', () => __awaiter(void 0, void 0, void 0, function* () {
    const ads = yield ad_record_1.AdRecord.findAll('nonexistent-name-fragment');
    expect(ads).toStrictEqual([]);
    expect(ads[0]).not.toBeDefined();
}));
//insert()
test('AdRecord.insert returns id', () => __awaiter(void 0, void 0, void 0, function* () {
    const id = yield newAd.insert();
    expect(id).toMatch(/^[0-9A-F]{8}-[0-9A-F]{4}-[4][0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i);
}));
test('AdRecord.insert inserts record to db', () => __awaiter(void 0, void 0, void 0, function* () {
    yield newAd.insert();
    const foundAd = yield ad_record_1.AdRecord.getOne(newAd.id);
    expect(foundAd).toBeDefined();
    expect(foundAd).not.toBeNull();
    expect(foundAd.id).toEqual(newAd.id);
}));
//# sourceMappingURL=ad.test.js.map